@@ -22,15 +22,16 @@ import helloworld_pb2_grpc
 
 
 async def run() -> None:
-    uds_addresses = ['unix:helloworld.sock', 'unix:///tmp/helloworld.sock']
+    uds_addresses = ["unix:helloworld.sock", "unix:///tmp/helloworld.sock"]
     for uds_address in uds_addresses:
         async with grpc.aio.insecure_channel(uds_address) as channel:
             stub = helloworld_pb2_grpc.GreeterStub(channel)
             response = await stub.SayHello(
-                helloworld_pb2.HelloRequest(name='you'))
-            logging.info('Received: %s', response.message)
+                helloworld_pb2.HelloRequest(name="you")
+            )
+            logging.info("Received: %s", response.message)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     logging.basicConfig(level=logging.INFO)
     asyncio.run(run())
