@@ -62,7 +62,7 @@ class EndToEndTest extends \PHPUnit\Framework\TestCase
             Grpc\OP_SEND_INITIAL_METADATA => [],
             Grpc\OP_SEND_STATUS_FROM_SERVER => [
                 'metadata' => [],
-                'code' => Grpc\STATUS_OK,
+                'code' => Grpc\STATUS_INVALID_ARGUMENT,
                 'details' => $status_text,
             ],
             Grpc\OP_RECV_CLOSE_ON_SERVER => true,
@@ -79,7 +79,7 @@ class EndToEndTest extends \PHPUnit\Framework\TestCase
 
         $status = $event->status;
         $this->assertSame([], $status->metadata);
-        $this->assertSame(Grpc\STATUS_OK, $status->code);
+        $this->assertSame(Grpc\STATUS_INVALID_ARGUMENT, $status->code);
         $this->assertSame($status_text, $status->details);
 
         unset($call);
@@ -90,7 +90,6 @@ class EndToEndTest extends \PHPUnit\Framework\TestCase
     {
         $deadline = Grpc\Timeval::infFuture();
         $req_text = 'message_write_flags_test';
-        $status_text = 'xyz';
         $call = new Grpc\Call($this->channel,
                               'phony_method',
                               $deadline);
@@ -114,7 +113,7 @@ class EndToEndTest extends \PHPUnit\Framework\TestCase
             Grpc\OP_SEND_STATUS_FROM_SERVER => [
                 'metadata' => [],
                 'code' => Grpc\STATUS_OK,
-                'details' => $status_text,
+                'details' => '',
             ],
         ]);
 
@@ -126,7 +125,6 @@ class EndToEndTest extends \PHPUnit\Framework\TestCase
         $status = $event->status;
         $this->assertSame([], $status->metadata);
         $this->assertSame(Grpc\STATUS_OK, $status->code);
-        $this->assertSame($status_text, $status->details);
 
         unset($call);
         unset($server_call);
@@ -137,7 +135,6 @@ class EndToEndTest extends \PHPUnit\Framework\TestCase
         $deadline = Grpc\Timeval::infFuture();
         $req_text = 'client_server_full_request_response';
         $reply_text = 'reply:client_server_full_request_response';
-        $status_text = 'status:client_server_full_response_text';
 
         $call = new Grpc\Call($this->channel,
                               'phony_method',
@@ -168,7 +165,7 @@ class EndToEndTest extends \PHPUnit\Framework\TestCase
             Grpc\OP_SEND_STATUS_FROM_SERVER => [
                 'metadata' => [],
                 'code' => Grpc\STATUS_OK,
-                'details' => $status_text,
+                'details' => '',
             ],
             Grpc\OP_RECV_CLOSE_ON_SERVER => true,
         ]);
@@ -189,7 +186,7 @@ class EndToEndTest extends \PHPUnit\Framework\TestCase
         $status = $event->status;
         $this->assertSame([], $status->metadata);
         $this->assertSame(Grpc\STATUS_OK, $status->code);
-        $this->assertSame($status_text, $status->details);
+        $this->assertSame("", $status->details);
 
         unset($call);
         unset($server_call);
