@@ -64,7 +64,7 @@ PACKAGE_DIRECTORIES = {
 }
 
 INSTALL_REQUIRES = (
-    "protobuf>=5.26.1,<6.0dev",
+    "protobuf>=6.31.1,<7.0.0",
     "grpcio>={version}".format(version=grpc_version.VERSION),
 )
 
