@@ -28,9 +28,9 @@ namespace grpc_core {
 namespace {
 // Tests that we can unref a call whose status is cached but not yet
 // requested by the application.  This should not cause a memory leak.
-CORE_END2END_TEST(RetryTest, RetryUnrefBeforeFinish) {
+CORE_END2END_TEST(RetryTests, RetryUnrefBeforeFinish) {
   if (!IsRetryInCallv3Enabled()) SKIP_IF_V3();
-  InitServer(ChannelArgs());
+  InitServer(DefaultServerArgs());
   InitClient(ChannelArgs().Set(
       GRPC_ARG_SERVICE_CONFIG,
       "{\n"
