@@ -17,15 +17,16 @@
 #include <thread>
 #include <vector>
 
-#include <gmock/gmock.h>
-#include <gtest/gtest.h>
-
-#include "src/core/ext/filters/client_channel/backup_poller.h"
-#include "src/core/lib/config/config_vars.h"
-#include "src/proto/grpc/testing/xds/v3/cluster.grpc.pb.h"
-#include "src/proto/grpc/testing/xds/v3/fault.grpc.pb.h"
-#include "src/proto/grpc/testing/xds/v3/outlier_detection.grpc.pb.h"
-#include "src/proto/grpc/testing/xds/v3/router.grpc.pb.h"
+#include "absl/log/check.h"
+#include "envoy/config/cluster/v3/cluster.pb.h"
+#include "envoy/config/cluster/v3/outlier_detection.pb.h"
+#include "envoy/extensions/filters/http/fault/v3/fault.pb.h"
+#include "envoy/extensions/filters/http/router/v3/router.pb.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
+#include "src/core/client_channel/backup_poller.h"
+#include "src/core/config/config_vars.h"
+#include "test/core/test_util/resolve_localhost_ip46.h"
 #include "test/cpp/end2end/xds/xds_end2end_test_lib.h"
 
 namespace grpc {
@@ -35,8 +36,8 @@ namespace {
 class OutlierDetectionTest : public XdsEnd2endTest {
  protected:
   std::string CreateMetadataValueThatHashesToBackend(int index) {
-    return absl::StrCat(ipv6_only_ ? "[::1]" : "127.0.0.1", ":",
-                        backends_[index]->port(), "_0");
+    return absl::StrCat(grpc_core::LocalIp(), ":", backends_[index]->port(),
+                        "_0");
   }
 };
 
@@ -79,7 +80,7 @@ TEST_P(OutlierDetectionTest, SuccessRateEjectionAndUnejection) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -139,7 +140,7 @@ TEST_P(OutlierDetectionTest, SuccessRateMaxPercent) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -183,7 +184,7 @@ TEST_P(OutlierDetectionTest, SuccessRateMaxPercent) {
     EXPECT_LE(absl::Now(), deadline);
     if (absl::Now() >= deadline) break;
   }
-  // 1 backend should be ejected, trafficed picked up by another backend.
+  // 1 backend should be ejected, traffic picked up by another backend.
   // No other backend should be ejected.
   ResetBackendCounters();
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options);
@@ -201,7 +202,7 @@ TEST_P(OutlierDetectionTest, SuccessRateMaxPercent) {
     } else if (backends_[i]->backend_service()->request_count() == 100) {
       ++regular_load_backend_count;
     } else {
-      GPR_ASSERT(1);
+      CHECK(1);
     }
   }
   EXPECT_EQ(1, empty_load_backend_count);
@@ -242,7 +243,7 @@ TEST_P(OutlierDetectionTest, SuccessRateStdevFactor) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -263,7 +264,7 @@ TEST_P(OutlierDetectionTest, SuccessRateStdevFactor) {
   gpr_sleep_until(grpc_timeout_milliseconds_to_deadline(
       3000 * grpc_test_slowdown_factor()));
   ResetBackendCounters();
-  // 1 backend experenced failure, but since the stdev_factor is high, no
+  // 1 backend experienced failure, but since the stdev_factor is high, no
   // backend will be noticed as an outlier so no ejection.
   // Both backends are still getting the RPCs intended for them.
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options);
@@ -302,7 +303,7 @@ TEST_P(OutlierDetectionTest, SuccessRateEnforcementPercentage) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -323,9 +324,9 @@ TEST_P(OutlierDetectionTest, SuccessRateEnforcementPercentage) {
   gpr_sleep_until(grpc_timeout_milliseconds_to_deadline(
       3000 * grpc_test_slowdown_factor()));
   ResetBackendCounters();
-  // 1 backend experenced failure, but since the enforcement percentage is 0, no
-  // backend will be ejected.
-  // Both backends are still getting the RPCs intended for them.
+  // 1 backend experienced failure, but since the enforcement percentage is 0,
+  // no backend will be ejected. Both backends are still getting the RPCs
+  // intended for them.
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options);
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options1);
   EXPECT_EQ(100, backends_[0]->backend_service()->request_count());
@@ -362,7 +363,7 @@ TEST_P(OutlierDetectionTest, SuccessRateMinimumHosts) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -423,7 +424,7 @@ TEST_P(OutlierDetectionTest, SuccessRateRequestVolume) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -486,7 +487,7 @@ TEST_P(OutlierDetectionTest, FailurePercentageEjectionAndUnejection) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -553,7 +554,7 @@ TEST_P(OutlierDetectionTest, FailurePercentageMaxPercentage) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -597,7 +598,7 @@ TEST_P(OutlierDetectionTest, FailurePercentageMaxPercentage) {
     EXPECT_LE(absl::Now(), deadline);
     if (absl::Now() >= deadline) break;
   }
-  // 1 backend should be ejected, trafficed picked up by another backend.
+  // 1 backend should be ejected, traffic picked up by another backend.
   // No other backend should be ejected.
   ResetBackendCounters();
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options);
@@ -615,7 +616,7 @@ TEST_P(OutlierDetectionTest, FailurePercentageMaxPercentage) {
     } else if (backends_[i]->backend_service()->request_count() == 100) {
       ++regular_load_backend_count;
     } else {
-      GPR_ASSERT(1);
+      CHECK(1);
     }
   }
   EXPECT_EQ(1, empty_load_backend_count);
@@ -652,7 +653,7 @@ TEST_P(OutlierDetectionTest, FailurePercentageThreshold) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -674,7 +675,7 @@ TEST_P(OutlierDetectionTest, FailurePercentageThreshold) {
   gpr_sleep_until(grpc_timeout_milliseconds_to_deadline(
       3000 * grpc_test_slowdown_factor()));
   ResetBackendCounters();
-  // 1 backend experenced 1 failure, but since the threshold is 50 % no
+  // 1 backend experienced 1 failure, but since the threshold is 50 % no
   // backend will be noticed as an outlier so no ejection.
   // Both backends are still getting the RPCs intended for them.
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options);
@@ -713,7 +714,7 @@ TEST_P(OutlierDetectionTest, FailurePercentageEnforcementPercentage) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -735,9 +736,9 @@ TEST_P(OutlierDetectionTest, FailurePercentageEnforcementPercentage) {
   gpr_sleep_until(grpc_timeout_milliseconds_to_deadline(
       3000 * grpc_test_slowdown_factor()));
   ResetBackendCounters();
-  // 1 backend experenced failure, but since the enforcement percentage is 0, no
-  // backend will be ejected.
-  // Both backends are still getting the RPCs intended for them.
+  // 1 backend experienced failure, but since the enforcement percentage is 0,
+  // no backend will be ejected. Both backends are still getting the RPCs
+  // intended for them.
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options);
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options1);
   EXPECT_EQ(100, backends_[0]->backend_service()->request_count());
@@ -778,7 +779,7 @@ TEST_P(OutlierDetectionTest, FailurePercentageMinimumHosts) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -841,7 +842,7 @@ TEST_P(OutlierDetectionTest, FailurePercentageRequestVolume) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -906,7 +907,7 @@ TEST_P(OutlierDetectionTest, SuccessRateAndFailurePercentage) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -932,7 +933,7 @@ TEST_P(OutlierDetectionTest, SuccessRateAndFailurePercentage) {
   // Cause 2 errors on 1 backend and 1 error on 2 backends and wait for 2
   // backends to be ejected. The 2 errors to the 1 backend will make exactly 1
   // outlier from the success rate algorithm; all 4 errors will make 3 outliers
-  // from the failure pecentage algorithm because the threahold is set to 0. I
+  // from the failure percentage algorithm because the threshold is set to 0. I
   // have verified through debug logs we eject 1 backend because of success
   // rate, 1 backend because of failure percentage; but as we attempt to eject
   // another backend because of failure percentage we will stop as we have
@@ -983,7 +984,7 @@ TEST_P(OutlierDetectionTest, SuccessRateAndFailurePercentage) {
       // The extra load could go to 2 remaining backends or just 1 of them.
       ++double_load_backend_count;
     } else if (backends_[i]->backend_service()->request_count() > 300) {
-      GPR_ASSERT(1);
+      CHECK(1);
     }
   }
   EXPECT_EQ(2, empty_load_backend_count);
@@ -1013,7 +1014,7 @@ TEST_P(OutlierDetectionTest, SuccessRateAndFailurePercentageBothDisabled) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -1034,7 +1035,7 @@ TEST_P(OutlierDetectionTest, SuccessRateAndFailurePercentageBothDisabled) {
   gpr_sleep_until(grpc_timeout_milliseconds_to_deadline(
       3000 * grpc_test_slowdown_factor()));
   ResetBackendCounters();
-  // 1 backend experenced failure, but since there is no counting there is no
+  // 1 backend experienced failure, but since there is no counting there is no
   // ejection.  Both backends are still getting the RPCs intended for them.
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options);
   CheckRpcSendOk(DEBUG_LOCATION, 100, rpc_options1);
@@ -1069,7 +1070,7 @@ TEST_P(OutlierDetectionTest, DisableOutlierDetectionWhileAddressesAreEjected) {
                                    new_route_config);
   EdsResourceArgs args({{"locality0", CreateEndpointsForBackends()}});
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
-  // Note each type of RPC will contains a header value that will always be
+  // Note each type of RPC will contain a header value that will always be
   // hashed to a specific backend as the header value matches the value used
   // to create the entry in the ring.
   std::vector<std::pair<std::string, std::string>> metadata = {
@@ -1114,6 +1115,58 @@ TEST_P(OutlierDetectionTest, DisableOutlierDetectionWhileAddressesAreEjected) {
           .set_server_expected_error(StatusCode::CANCELLED));
 }
 
+TEST_P(OutlierDetectionTest, EjectionRetainedAcrossPriorities) {
+  CreateAndStartBackends(3);
+  auto cluster = default_cluster_;
+  // Setup outlier failure percentage parameters.
+  // Any failure will cause an potential ejection with the probability of 100%
+  // (to eliminate flakiness of the test).
+  auto* outlier_detection = cluster.mutable_outlier_detection();
+  SetProtoDuration(grpc_core::Duration::Seconds(1),
+                   outlier_detection->mutable_interval());
+  SetProtoDuration(grpc_core::Duration::Minutes(10),
+                   outlier_detection->mutable_base_ejection_time());
+  outlier_detection->mutable_failure_percentage_threshold()->set_value(0);
+  outlier_detection->mutable_enforcing_failure_percentage()->set_value(100);
+  outlier_detection->mutable_failure_percentage_minimum_hosts()->set_value(1);
+  outlier_detection->mutable_failure_percentage_request_volume()->set_value(1);
+  balancer_->ads_service()->SetCdsResource(cluster);
+  // Priority 0: backend 0 and a non-existent backend.
+  // Priority 1: backend 1.
+  EdsResourceArgs args({
+      {"locality0", {CreateEndpoint(0), MakeNonExistentEndpoint()}},
+      {"locality1", {CreateEndpoint(1)}, kDefaultLocalityWeight, 1},
+  });
+  balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
+  WaitForBackend(DEBUG_LOCATION, 0);
+  // Trigger an error to backend 0.
+  // The success rate enforcement_percentage is 100%, so this will cause
+  // the backend to be ejected when the ejection timer fires.
+  CheckRpcSendFailure(
+      DEBUG_LOCATION, StatusCode::CANCELLED, "",
+      RpcOptions().set_server_expected_error(StatusCode::CANCELLED));
+  // Wait for traffic aimed at backend 0 to start going to backend 1.
+  // This tells us that backend 0 has been ejected.
+  // It should take no more than one ejection timer interval.
+  WaitForBackend(DEBUG_LOCATION, 1, /*check_status=*/nullptr,
+                 WaitForBackendOptions().set_timeout_ms(
+                     3000 * grpc_test_slowdown_factor()));
+  // Now send an EDS update that moves backend 0 to priority 1.
+  // We also add backend 2, so that we know when the client sees the update.
+  args = EdsResourceArgs({
+      {"locality0", {MakeNonExistentEndpoint()}},
+      {"locality1", CreateEndpointsForBackends(), kDefaultLocalityWeight, 1},
+  });
+  balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
+  WaitForBackend(DEBUG_LOCATION, 2);
+  // Now send 100 RPCs and make sure they all go to backends 1 and 2,
+  // because backend 0 should still be ejected.
+  CheckRpcSendOk(DEBUG_LOCATION, 100);
+  EXPECT_EQ(0, backends_[0]->backend_service()->request_count());
+  EXPECT_EQ(50, backends_[1]->backend_service()->request_count());
+  EXPECT_EQ(50, backends_[2]->backend_service()->request_count());
+}
+
 }  // namespace
 }  // namespace testing
 }  // namespace grpc
