@@ -30,7 +30,10 @@ python3 tools/run_tests/python_utils/bazel_report_helper.py --report_path bazel_
 
 bazel_rbe/bazel_wrapper \
   --bazelrc=tools/remote_build/linux_kokoro.bazelrc \
+  --output_user_root=/tmpfs/bazel \
   test \
   $BAZEL_FLAGS \
+  --generate_json_trace_profile \
+  --profile=bazel_rbe/profile.json \
   "$@" \
   -- ${BAZEL_TESTS:-//test/...}
